Cast an object to a timespan
as.timespan(x, ..., format = parse_iso8601_datetime_as_timespan)A partial_time object. See the Details section of timespan
for more information.
an object to cast
Additional arguments passed to format when a function is
provided.
a function or character value. If a
function, it should accept a character vector and return a matrix of
parttime components. If a character it should provide a regular
exprssion which contains capture groups for each of the parttime
components. See parse_to_parttime_matrix's regex parameter
for more details.